@@ -1,6 +1,6 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2001, 2006-2009 Peter Miller
+ *      Copyright (C) 1999, 2001, 2006-2010 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -234,6 +234,7 @@ fp_subdir_write(fp_subdir_ty *this, int *need_to_write_dot)
         switch (errno)
         {
         case ENOENT:
+        case ENOSYS:
             break;
 
         case EACCES:
@@ -257,7 +258,7 @@ fp_subdir_write(fp_subdir_ty *this, int *need_to_write_dot)
     fp = fopen(fn->str_text, "w");
     if (!fp)
     {
-        if (errno == EACCES || errno == ENOENT)
+        if (errno == EACCES || errno == ENOENT || errno == ENOSYS)
         {
             str_free(fn);
             trace(("mark not writable any more\n"));
