@@ -1,6 +1,6 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1993-2007, 2009 Peter Miller
+ *      Copyright (C) 1993-2007, 2009, 2010 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -38,16 +38,16 @@
 #include <common/symtab.h>
 #include <common/trace.h>
 #include <cook/expr.h>
-#include <cook/expr/list.h>     /* for parse.gen.h */
+#include <cook/expr/list.h>     /* for parse.yacc.h */
 #include <cook/hashline.h>
 #include <cook/lex.h>
 #include <cook/lex/filename.h>
 #include <cook/lex/filenamelist.h>
 #include <cook/option.h>
 #include <cook/stmt.h>
-#include <cook/stmt/list.h>     /* for parse.gen.h */
-#include <cook/parse.gen.h>     /* must be last */
-#include <cook/hashline.gen.h>  /* must be last */
+#include <cook/stmt/list.h>     /* for parse.yacc.h */
+#include <cook/parse.yacc.h>     /* must be last */
+#include <cook/hashline.yacc.h>  /* must be last */
 
 
 /*
