@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1999, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1999, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate statement lists
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/mem.h>
@@ -40,7 +37,7 @@
 void
 stmt_list_append(stmt_list_ty *sl, stmt_ty *s)
 {
-    trace(("stmt_list_append(sl = %08X, s = %08X)\n{\n", sl, s));
+    trace(("stmt_list_append(sl = %p, s = %p)\n{\n", sl, s));
     if (sl->sl_nstmts >= sl->sl_nstmts_max)
     {
         size_t          nbytes;
@@ -74,7 +71,7 @@ stmt_list_destructor(stmt_list_ty *sl)
 {
     size_t          j;
 
-    trace(("stmt_list_destructor(sl = %08X)\n{\n", sl));
+    trace(("stmt_list_destructor(sl = %p)\n{\n", sl));
     for (j = 0; j < sl->sl_nstmts; ++j)
         stmt_delete(sl->sl_stmt[j]);
     if (sl->sl_stmt)
