@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #       cook - file construction tool
-#       Copyright (C) 1994, 1996, 1997, 2002, 2007-2009 Peter Miller
+#       Copyright (C) 1994, 1996, 1997, 2002, 2007-2010 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -27,8 +27,6 @@ tr ' ' '\12' |
 sort -V $sortflag |
 while read f
 do
-    echo ".br"
-    echo ".ne 1i"
     echo ".so $f"
 done
 exit 0
