@@ -2,7 +2,7 @@
 .\"     cook - file construction tool
 .\"     Copyright (C) 2002 Aryeh M. Friedman
 .\"     Groff formatting general editorial work
-.\"     Copyright (C) 2002, 2003, 2007, 2009 Peter Miller
+.\"     Copyright (C) 2002, 2003, 2007, 2009, 2010 Peter Miller
 .\"
 .\"     This program is free software; you can redistribute it and/or modify
 .\"     it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@
 .if t .ds HP 16 14 12 12 10 10 10 10 10 10
 .PH "''''"
 .PF "''''"
-.so libdir.so \"from the etc directory, by configure
-.so version.so \"from the etc directory
+.so etc/libdir.so
+.so etc/version.so
 .\" stuff for figuring dates
 .\"
 .ds MONTH1 January
@@ -448,7 +448,7 @@ By default cook looks for the cookbook in "Howto.cook" [note 1].
 .H 1 "A Sample Project"
 For the remainder of the tutorial we will be using the following
 sample project source tree:
-.so fig1.so
+.so lib/en/tutorial/fig1.so
 .P
 The final output of the build process will be completely working
 and installed executables of prog1 and prog2 installed in /usr/local/bin and
@@ -467,7 +467,7 @@ in our sample project the graph would be:
 .\" P2;prog2
 .\" .TE
 .P
-.so fig2.so
+.so lib/en/tutorial/fig2.so
 .P
 .ft R
 Now we know enough to write the first version of our cookbook.
