@@ -1,6 +1,6 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1994, 1997, 1998, 2001, 2002, 2006-2009 Peter Miller
+ *      Copyright (C) 1994, 1997, 1998, 2001, 2002, 2006-2010 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include <common/trace.h>
 #include <make2cook/vargram.h>
 #include <make2cook/variable.h>
-#include <make2cook/vargram.gen.h>      /* must be last */
+#include <make2cook/vargram.yacc.h>      /* must be last */
 
 
 static blob_ty *source;
